import inspect


class CopyObject:

    def get_all_fields(self, klass_object):
        klass_props = []
        if klass_object:
            for props in inspect.getmembers(klass_object):
                pass
        return klass_props

    def copy(self, source, destination):
        self.get_all_fields(destination)
        pass


def is_it_dictionary(data):
    return isinstance(data, dict)


def is_it_string(data):
    return isinstance(data, str)


def is_it_list(data):
    return isinstance(data, list)


def is_it_integer(data):
    return isinstance(data, int)


def is_it_float(data):
    return isinstance(data, float)





from setuptools import setup, find_packages

setup(
    name='pf-py-object-man',
    version='1.1',
    url='https://github.com/problemfighter/pf-py-object-man',
    license='Apache 2.0',
    author='Touhid Mia',
    author_email='hmtm.cse@gmail.com',
    description='Problem Fighter Python Object Manager',
    long_description=__doc__,
    packages=find_packages(),
    zip_safe=False,
    include_package_data=True,
    platforms='any',
    install_requires=[],
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)